@@ -34,6 +34,8 @@ void		 gs_app_set_priority		(GsApp		*app,
 guint		 gs_app_get_priority		(GsApp		*app);
 void		 gs_app_set_unique_id		(GsApp		*app,
 						 const gchar	*unique_id);
+void		 gs_app_remove_addon		(GsApp		*app,
+						 GsApp		*addon);
 
 G_END_DECLS
 
