@@ -319,7 +319,7 @@ gs_app_row_refresh (GsAppRow *app_row)
 	}
 
 	/* add warning */
-	if (gs_app_get_kind (priv->app) == AS_APP_KIND_FIRMWARE) {
+	if (gs_app_has_quirk (priv->app, AS_APP_QUIRK_REMOVABLE_HARDWARE)) {
 		gtk_label_set_text (GTK_LABEL (priv->label_warning),
 				    /* TRANSLATORS: during the update the device
 				     * will restart into a special update-only mode */
