@@ -44,6 +44,14 @@ void		 gs_app_row_refresh			(GsAppRow	*app_row);
 void		 gs_app_row_unreveal			(GsAppRow	*app_row);
 void		 gs_app_row_set_colorful		(GsAppRow	*app_row,
 							 gboolean	 colorful);
+void		 gs_app_row_set_show_folders		(GsAppRow	*app_row,
+							 gboolean	 show_folders);
+void		 gs_app_row_set_show_buttons		(GsAppRow	*app_row,
+							 gboolean	 show_buttons);
+void		 gs_app_row_set_show_sandbox		(GsAppRow	*app_row,
+							 gboolean	 show_sandbox);
+void		 gs_app_row_set_show_source		(GsAppRow	*app_row,
+							 gboolean	 show_source);
 void		 gs_app_row_set_show_codec		(GsAppRow	*app_row,
 							 gboolean	 show_codec);
 void		 gs_app_row_set_show_update		(GsAppRow	*app_row,
