@@ -184,6 +184,8 @@ _as_app_quirk_flag_to_string (AsAppQuirk quirk)
 		return "not-launchable";
 	if (quirk == AS_APP_QUIRK_NEEDS_USER_ACTION)
 		return "needs-user-action";
+	if (quirk == AS_APP_QUIRK_REMOVABLE_HARDWARE)
+		return "removable-hardware";
 	return NULL;
 }
 
@@ -1933,7 +1935,7 @@ gs_app_get_origin (GsApp *app)
 void
 gs_app_set_origin (GsApp *app, const gchar *origin)
 {
-	g_autoptr(GMutexLocker) locker = g_mutex_locker_new (&app->mutex);
+	g_autoptr(GMutexLocker) locker = NULL;
 	g_return_if_fail (GS_IS_APP (app));
 	if (origin == app->origin)
 		return;
@@ -1947,6 +1949,7 @@ gs_app_set_origin (GsApp *app, const gchar *origin)
 		return;
 	}
 
+	locker = g_mutex_locker_new (&app->mutex);
 	g_free (app->origin);
 	app->origin = g_strdup (origin);
 
