@@ -492,7 +492,7 @@ gs_plugin_loader_app_action_finish_sync (GsPluginLoader *plugin_loader,
 gboolean
 gs_plugin_loader_app_action (GsPluginLoader *plugin_loader,
 			     GsApp *app,
-			     GsPluginLoaderAction action,
+			     GsPluginAction action,
 			     GCancellable *cancellable,
 			     GError **error)
 {
@@ -537,7 +537,7 @@ gboolean
 gs_plugin_loader_review_action (GsPluginLoader *plugin_loader,
 				GsApp *app,
 				AsReview *review,
-				GsPluginReviewAction action,
+				GsPluginAction action,
 				GCancellable *cancellable,
 				GError **error)
 {
@@ -582,7 +582,7 @@ gs_plugin_loader_auth_action_finish_sync (GsPluginLoader *plugin_loader,
 gboolean
 gs_plugin_loader_auth_action (GsPluginLoader *plugin_loader,
 			      GsAuth *auth,
-			      GsAuthAction action,
+			      GsPluginAction action,
 			      GCancellable *cancellable,
 			      GError **error)
 {
