@@ -30,7 +30,7 @@
 
 struct _GsPopularTile
 {
-	GtkButton	 parent_instance;
+	GsAppTile	 parent_instance;
 
 	GsApp		*app;
 	GtkWidget	*label;
@@ -40,14 +40,12 @@ struct _GsPopularTile
 	GtkWidget	*stars;
 };
 
-G_DEFINE_TYPE (GsPopularTile, gs_popular_tile, GTK_TYPE_BUTTON)
+G_DEFINE_TYPE (GsPopularTile, gs_popular_tile, GS_TYPE_APP_TILE)
 
-GsApp *
-gs_popular_tile_get_app (GsPopularTile *tile)
+static GsApp *
+gs_popular_tile_get_app (GsAppTile *tile)
 {
-	g_return_val_if_fail (GS_IS_POPULAR_TILE (tile), NULL);
-
-	return tile->app;
+	return GS_POPULAR_TILE (tile)->app;
 }
 
 static gboolean
@@ -100,10 +98,11 @@ app_state_changed (GsApp *app, GParamSpec *pspec, GsPopularTile *tile)
 	g_idle_add (app_state_changed_idle, g_object_ref (tile));
 }
 
-void
-gs_popular_tile_set_app (GsPopularTile *tile, GsApp *app)
+static void
+gs_popular_tile_set_app (GsAppTile *app_tile, GsApp *app)
 {
-	g_return_if_fail (GS_IS_POPULAR_TILE (tile));
+	GsPopularTile *tile = GS_POPULAR_TILE (app_tile);
+
 	g_return_if_fail (GS_IS_APP (app) || app == NULL);
 
 	if (tile->app)
@@ -114,11 +113,11 @@ gs_popular_tile_set_app (GsPopularTile *tile, GsApp *app)
 		return;
 
 	if (gs_app_get_rating (tile->app) >= 0) {
-		gtk_widget_set_visible (tile->stars, TRUE);
+		gtk_widget_set_sensitive (tile->stars, TRUE);
 		gs_star_widget_set_rating (GS_STAR_WIDGET (tile->stars),
 					   gs_app_get_rating (tile->app));
 	} else {
-		gtk_widget_set_visible (tile->stars, FALSE);
+		gtk_widget_set_sensitive (tile->stars, FALSE);
 	}
 	gtk_stack_set_visible_child_name (GTK_STACK (tile->stack), "content");
 
@@ -127,8 +126,8 @@ gs_popular_tile_set_app (GsPopularTile *tile, GsApp *app)
 	app_state_changed (tile->app, NULL, tile);
 
 	/* perhaps set custom css */
-	gs_utils_widget_set_custom_css (app, GTK_WIDGET (tile),
-					"GnomeSoftware::PopularTile-css");
+	gs_utils_widget_set_css_app (app, GTK_WIDGET (tile),
+				     "GnomeSoftware::PopularTile-css");
 
 	gs_image_set_from_pixbuf (GTK_IMAGE (tile->image), gs_app_get_pixbuf (tile->app));
 
@@ -160,9 +159,13 @@ static void
 gs_popular_tile_class_init (GsPopularTileClass *klass)
 {
 	GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
+	GsAppTileClass *app_tile_class = GS_APP_TILE_CLASS (klass);
 
 	widget_class->destroy = gs_popular_tile_destroy;
 
+	app_tile_class->set_app = gs_popular_tile_set_app;
+	app_tile_class->get_app = gs_popular_tile_get_app;
+
 	gtk_widget_class_set_template_from_resource (widget_class, "/org/gnome/Software/gs-popular-tile.ui");
 
 	gtk_widget_class_bind_template_child (widget_class, GsPopularTile, label);
@@ -178,7 +181,7 @@ gs_popular_tile_new (GsApp *app)
 	GsPopularTile *tile;
 
 	tile = g_object_new (GS_TYPE_POPULAR_TILE, NULL);
-	gs_popular_tile_set_app (tile, app);
+	gs_app_tile_set_app (GS_APP_TILE (tile), app);
 
 	return GTK_WIDGET (tile);
 }
