@@ -564,6 +564,7 @@ gs_shell_details_refresh_screenshots (GsShellDetails *self)
 	/* fallback warning */
 	screenshots = gs_app_get_screenshots (self->app);
 	switch (gs_app_get_kind (self->app)) {
+	case AS_APP_KIND_GENERIC:
 	case AS_APP_KIND_CODEC:
 	case AS_APP_KIND_ADDON:
 	case AS_APP_KIND_SOURCE:
@@ -1438,12 +1439,9 @@ gs_shell_details_file_to_app_cb (GObject *source,
 }
 
 void
-gs_shell_details_set_filename (GsShellDetails *self, const gchar *filename)
+gs_shell_details_set_local_file (GsShellDetails *self, GFile *file)
 {
-	g_autoptr(GFile) file = NULL;
-
 	gs_shell_details_set_state (self, GS_SHELL_DETAILS_STATE_LOADING);
-	file = g_file_new_for_path (filename);
 	gs_plugin_loader_file_to_app_async (self->plugin_loader,
 					    file,
 					    GS_PLUGIN_REFINE_FLAGS_REQUIRE_ICON |
@@ -1820,6 +1818,8 @@ gs_shell_details_license_free_cb (GtkWidget *widget, GsShellDetails *self)
 			continue;
 		if (g_strcmp0 (tokens[i], "|") == 0)
 			continue;
+		if (g_strcmp0 (tokens[i], "+") == 0)
+			continue;
 
 		/* add widget */
 		w = gs_shell_details_license_widget_for_token (self, tokens[i]);
