@@ -44,7 +44,6 @@ struct _GsShellSearch
 	gchar			*appid_to_show;
 	gchar			*value;
 	guint			 waiting_id;
-	GtkWidget		*search_button;
 
 	GtkWidget		*list_box_search;
 	GtkWidget		*scrolledwindow_search;
@@ -134,7 +133,6 @@ gs_shell_search_get_search_cb (GObject *source_object,
 	for (i = 0; i < gs_app_list_length (list); i++) {
 		app = gs_app_list_index (list, i);
 		app_row = gs_app_row_new (app);
-		gs_app_row_set_show_sandbox (GS_APP_ROW (app_row), TRUE);
 		if (!gs_app_has_quirk (app, AS_APP_QUIRK_PROVENANCE) ||
 		    gs_utils_list_has_app_fuzzy (list, app))
 			gs_app_row_set_show_source (GS_APP_ROW (app_row), TRUE);
@@ -254,7 +252,8 @@ gs_shell_search_switch_to (GsPage *page, gboolean scroll_up)
 	gtk_widget_show (widget);
 
 	/* hardcode */
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (self->search_button), TRUE);
+	widget = GTK_WIDGET (gtk_builder_get_object (self->builder, "search_button"));
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), TRUE);
 
 	if (scroll_up) {
 		GtkAdjustment *adj;
@@ -381,14 +380,6 @@ gs_shell_search_app_removed (GsPage *page, GsApp *app)
 	gs_shell_search_reload (page);
 }
 
-static void
-gs_shell_search_search_button_cb (GtkButton *button, GsShellSearch *self)
-{
-	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)))
-		return;
-	gs_shell_change_mode (self->shell, GS_SHELL_MODE_OVERVIEW, NULL, TRUE);
-}
-
 void
 gs_shell_search_setup (GsShellSearch *self,
 		       GsShell *shell,
@@ -418,12 +409,6 @@ gs_shell_search_setup (GsShellSearch *self,
 				    gs_shell_search_sort_func,
 				    self, NULL);
 
-	/* search button */
-	self->search_button = gs_search_button_new (NULL);
-	gs_page_set_header_end_widget (GS_PAGE (self), self->search_button);
-	g_signal_connect (self->search_button, "clicked",
-			  G_CALLBACK (gs_shell_search_search_button_cb), self);
-
 	/* chain up */
 	gs_page_setup (GS_PAGE (self),
 	               shell,
