@@ -302,11 +302,11 @@ gs_shell_updates_update_ui_state (GsShellUpdates *self)
 	/* headerbar refresh icon */
 	switch (self->state) {
 	case GS_SHELL_UPDATES_STATE_ACTION_REFRESH:
+	case GS_SHELL_UPDATES_STATE_ACTION_GET_UPDATES:
 		gtk_image_set_from_icon_name (GTK_IMAGE (gtk_button_get_image (GTK_BUTTON (self->button_refresh))),
 					      "media-playback-stop-symbolic", GTK_ICON_SIZE_MENU);
 		gtk_widget_show (self->button_refresh);
 		break;
-	case GS_SHELL_UPDATES_STATE_ACTION_GET_UPDATES:
 	case GS_SHELL_UPDATES_STATE_STARTUP:
 	case GS_SHELL_UPDATES_STATE_MANAGED:
 		gtk_widget_hide (self->button_refresh);
@@ -338,8 +338,11 @@ gs_shell_updates_update_ui_state (GsShellUpdates *self)
 	case GS_SHELL_UPDATES_STATE_FAILED:
 		gtk_stack_set_visible_child_name (GTK_STACK (self->stack_updates), "failed");
 		break;
-	case GS_SHELL_UPDATES_STATE_ACTION_REFRESH:
 	case GS_SHELL_UPDATES_STATE_ACTION_GET_UPDATES:
+		gtk_stack_set_visible_child_name (GTK_STACK (self->stack_updates),
+						  "spinner");
+		break;
+	case GS_SHELL_UPDATES_STATE_ACTION_REFRESH:
 		if (self->result_flags != GS_SHELL_UPDATES_FLAG_NONE) {
 			gtk_stack_set_visible_child_name (GTK_STACK (self->stack_updates), "view");
 		} else {
@@ -554,6 +557,7 @@ gs_shell_updates_get_upgrades_cb (GObject *source_object,
 		}
 	} else if (gs_app_list_length (list) == 0) {
 		g_debug ("updates-shell: no upgrades to show");
+		gs_shell_updates_clear_flag (self, GS_SHELL_UPDATES_FLAG_HAS_UPGRADES);
 	} else {
 		GsApp *app = gs_app_list_index (list, 0);
 		g_debug ("got upgrade %s", gs_app_get_id (app));
