@@ -47,13 +47,6 @@ struct _GsFlatpak {
 
 G_DEFINE_TYPE (GsFlatpak, gs_flatpak, G_TYPE_OBJECT)
 
-/* we have to do this until we hard dep on 0.6.11 */
-#define _FLATPAK_CHECK_VERSION(major,minor,micro)    \
-    (FLATPAK_MAJOR_VERSION > (major) || \
-     (FLATPAK_MAJOR_VERSION == (major) && FLATPAK_MINOR_VERSION > (minor)) || \
-     (FLATPAK_MAJOR_VERSION == (major) && FLATPAK_MINOR_VERSION == (minor) && \
-      FLATPAK_MICRO_VERSION >= (micro)))
-
 static gboolean
 gs_flatpak_refresh_appstream (GsFlatpak *self, guint cache_age,
 			      GsPluginRefreshFlags flags,
@@ -2254,6 +2247,18 @@ gs_flatpak_file_to_app_repo (GsFlatpak *self,
 		return FALSE;
 	}
 
+	/* check version */
+	if (g_key_file_has_key (kf, "Flatpak Repo", "Version", NULL)) {
+		guint64 ver = g_key_file_get_uint64 (kf, "Flatpak Repo", "Version", NULL);
+		if (ver != 1) {
+			g_set_error (error,
+				     GS_PLUGIN_ERROR,
+				     GS_PLUGIN_ERROR_NOT_SUPPORTED,
+				     "unsupported version %" G_GUINT64_FORMAT, ver);
+			return FALSE;
+		}
+	}
+
 	/* user specified a URL */
 	if (g_str_has_prefix (repo_gpgkey, "http://") ||
 	    g_str_has_prefix (repo_gpgkey, "https://")) {
@@ -2326,8 +2331,14 @@ gs_flatpak_file_to_app_ref (GsFlatpak *self,
 	g_autoptr(GBytes) ref_file_data = NULL;
 	g_autoptr(GsApp) app = NULL;
 	g_autoptr(FlatpakRemote) xremote = NULL;
+	g_autoptr(GKeyFile) kf = NULL;
 	g_autofree gchar *origin_url = NULL;
 	g_autofree gchar *origin_title = NULL;
+	g_autofree gchar *ref_comment = NULL;
+	g_autofree gchar *ref_description = NULL;
+	g_autofree gchar *ref_homepage = NULL;
+	g_autofree gchar *ref_icon = NULL;
+	g_autofree gchar *ref_title = NULL;
 
 	/* get file data */
 	if (!g_file_load_contents (file,
@@ -2339,7 +2350,24 @@ gs_flatpak_file_to_app_ref (GsFlatpak *self,
 		return FALSE;
 	}
 
-#if _FLATPAK_CHECK_VERSION(0,6,10)
+	/* load the file */
+	kf = g_key_file_new ();
+	if (!g_key_file_load_from_data (kf, contents, len, G_KEY_FILE_NONE, error)) {
+		return FALSE;
+	}
+
+	/* check version */
+	if (g_key_file_has_key (kf, "Flatpak Ref", "Version", NULL)) {
+		guint64 ver = g_key_file_get_uint64 (kf, "Flatpak Ref", "Version", NULL);
+		if (ver != 1) {
+			g_set_error (error,
+				     GS_PLUGIN_ERROR,
+				     GS_PLUGIN_ERROR_NOT_SUPPORTED,
+				     "unsupported version %" G_GUINT64_FORMAT, ver);
+			return FALSE;
+		}
+	}
+
 	/* install the remote, but not the app */
 	ref_file_data = g_bytes_new (contents, len);
 	xref = flatpak_installation_install_ref_file (self->installation,
@@ -2349,13 +2377,6 @@ gs_flatpak_file_to_app_ref (GsFlatpak *self,
 	if (xref == NULL) {
 		return FALSE;
 	}
-#else
-	g_set_error_literal (error,
-			     GS_PLUGIN_ERROR,
-			     GS_PLUGIN_ERROR_NOT_SUPPORTED,
-			     "not new enough libflatpak to support flatpakref");
-	return FALSE;
-#endif
 
 	/* load metadata */
 	app = gs_plugin_create_app (self, FLATPAK_REF (xref));
@@ -2364,7 +2385,26 @@ gs_flatpak_file_to_app_ref (GsFlatpak *self,
 	gs_app_set_state (app, AS_APP_STATE_AVAILABLE_LOCAL);
 	gs_flatpak_set_metadata (self, app, FLATPAK_REF (xref));
 
-	/* FIXME: perhaps use the data from the flatpakref file as a fallback? */
+	/* use the data from the flatpakref file as a fallback */
+	ref_title = g_key_file_get_string (kf, "Flatpak Ref", "Title", NULL);
+	if (ref_title != NULL)
+		gs_app_set_name (app, GS_APP_QUALITY_NORMAL, ref_title);
+	ref_comment = g_key_file_get_string (kf, "Flatpak Ref", "Comment", NULL);
+	if (ref_comment != NULL)
+		gs_app_set_summary (app, GS_APP_QUALITY_NORMAL, ref_comment);
+	ref_description = g_key_file_get_string (kf, "Flatpak Ref", "Description", NULL);
+	if (ref_description != NULL)
+		gs_app_set_description (app, GS_APP_QUALITY_NORMAL, ref_description);
+	ref_homepage = g_key_file_get_string (kf, "Flatpak Ref", "Homepage", NULL);
+	if (ref_homepage != NULL)
+		gs_app_set_url (app, AS_URL_KIND_HOMEPAGE, ref_homepage);
+	ref_icon = g_key_file_get_string (kf, "Flatpak Ref", "Icon", NULL);
+	if (ref_icon != NULL) {
+		g_autoptr(AsIcon) ic = as_icon_new ();
+		as_icon_set_kind (ic, AS_ICON_KIND_REMOTE);
+		as_icon_set_url (ic, ref_icon);
+		gs_app_add_icon (app, ic);
+	}
 
 	/* set the origin data */
 	remote_name = flatpak_remote_ref_get_remote_name (xref);
