@@ -79,6 +79,7 @@ gs_plugin_adopt_app (GsPlugin *plugin, GsApp *app)
 	if (g_strcmp0 (gs_app_get_id (app), "mate-spell.desktop") == 0 ||
 	    g_strcmp0 (gs_app_get_id (app), "chiron.desktop") == 0 ||
 	    g_strcmp0 (gs_app_get_id (app), "zeus.desktop") == 0 ||
+	    g_strcmp0 (gs_app_get_id (app), "com.hughski.ColorHug2.driver") == 0 ||
 	    g_strcmp0 (gs_app_get_id (app), "zeus-spell.addon") == 0 ||
 	    g_strcmp0 (gs_app_get_source_default (app), "chiron") == 0)
 		gs_app_set_management_plugin (app, gs_plugin_get_name (plugin));
@@ -388,6 +389,7 @@ gs_plugin_refine_app (GsPlugin *plugin,
 	/* default */
 	if (g_strcmp0 (gs_app_get_id (app), "chiron.desktop") == 0 ||
 	    g_strcmp0 (gs_app_get_id (app), "mate-spell.desktop") == 0 ||
+	    g_strcmp0 (gs_app_get_id (app), "com.hughski.ColorHug2.driver") == 0 ||
 	    g_strcmp0 (gs_app_get_id (app), "zeus.desktop") == 0) {
 		if (gs_app_get_state (app) == AS_APP_STATE_UNKNOWN)
 			gs_app_set_state (app, AS_APP_STATE_INSTALLED);
@@ -702,14 +704,9 @@ gs_plugin_auth_login (GsPlugin *plugin, GsAuth *auth,
 		       gs_auth_get_provider_id (priv->auth)) != 0)
 		return TRUE;
 
-	/* already done */
-	if (priv->has_auth) {
-		g_set_error (error,
-			     GS_PLUGIN_ERROR,
-			     GS_PLUGIN_ERROR_FAILED,
-			     "authentication already done");
-		return FALSE;
-	}
+	/* already logged in */
+	if (priv->has_auth)
+		return TRUE;
 
 	/* check username and password */
 	if (g_strcmp0 (gs_auth_get_username (priv->auth), "dummy") != 0 ||
@@ -738,14 +735,10 @@ gs_plugin_auth_logout (GsPlugin *plugin, GsAuth *auth,
 		       gs_auth_get_provider_id (priv->auth)) != 0)
 		return TRUE;
 
-	/* not done */
-	if (!priv->has_auth) {
-		g_set_error (error,
-			     GS_PLUGIN_ERROR,
-			     GS_PLUGIN_ERROR_FAILED,
-			     "authentication not already done");
-		return FALSE;
-	}
+	/* not logged in */
+	if (!priv->has_auth)
+		return TRUE;
+
 	priv->has_auth = FALSE;
 	gs_auth_set_flags (priv->auth, 0);
 	g_debug ("dummy now not authenticated");
