@@ -113,7 +113,7 @@ gs_plugin_app_install (GsPlugin *plugin, GsApp *app,
 	if (icons->len == 0) {
 		g_set_error (error,
 			     GS_PLUGIN_ERROR,
-			     GS_PLUGIN_ERROR_FAILED,
+			     GS_PLUGIN_ERROR_NOT_SUPPORTED,
 			     "no icons for %s",
 			     gs_app_get_id (app));
 		return FALSE;
@@ -130,7 +130,7 @@ gs_plugin_app_install (GsPlugin *plugin, GsApp *app,
 		} else {
 			g_set_error (error,
 				     GS_PLUGIN_ERROR,
-				     GS_PLUGIN_ERROR_FAILED,
+				     GS_PLUGIN_ERROR_WRITE_FAILED,
 				     "Can't symlink icon: %s",
 				     error_local->message);
 			return FALSE;
@@ -266,7 +266,7 @@ gs_plugin_refine_app (GsPlugin *plugin,
 	if (name == NULL) {
 		g_set_error (error,
 			     GS_PLUGIN_ERROR,
-			     GS_PLUGIN_ERROR_FAILED,
+			     GS_PLUGIN_ERROR_INVALID_FORMAT,
 			     "name unset for %s",
 			     gs_app_get_id (app));
 		return FALSE;
