@@ -142,7 +142,7 @@ gs_plugin_packagekit_refresh_guess_app_id (GsPlugin *plugin,
 	if (array->len == 0) {
 		g_set_error (error,
 			     GS_PLUGIN_ERROR,
-			     GS_PLUGIN_ERROR_FAILED,
+			     GS_PLUGIN_ERROR_INVALID_FORMAT,
 			     "no files for %s", filename);
 		return FALSE;
 	}
@@ -222,14 +222,14 @@ gs_plugin_file_to_app (GsPlugin *plugin,
 	if (array->len == 0) {
 		g_set_error (error,
 			     GS_PLUGIN_ERROR,
-			     GS_PLUGIN_ERROR_FAILED,
+			     GS_PLUGIN_ERROR_INVALID_FORMAT,
 			     "no details for %s", filename);
 		return FALSE;
 	}
 	if (array->len > 1) {
 		g_set_error (error,
 			     GS_PLUGIN_ERROR,
-			     GS_PLUGIN_ERROR_FAILED,
+			     GS_PLUGIN_ERROR_INVALID_FORMAT,
 			     "too many details [%u] for %s",
 			     array->len, filename);
 		return FALSE;
